import {ChangeDetectorRef, Component, OnInit} from '@angular/core';
import {ScannerService} from "../scanner.service";
import {ActivatedRoute, Router} from "@angular/router";
import {LoaderService} from "../../../core/services/loader.service";

@Component({
  selector: 'app-scan-completed',
  templateUrl: './scan-completed.component.html'
})
export class ScanCompletedComponent implements OnInit {

  constructor(private service: ScannerService,
              private route: ActivatedRoute,
              private loaderService: LoaderService,
              private changeDetector: ChangeDetectorRef,
              private router: Router) {
  }

  get originalUrl(): string {
    return this.service.originalUrl;
  }

  set originalUrl(value: string) {
    this.service.originalUrl = value;
  }

  get scannedUrl(): string {
    return this.service.scannedUrl;
  }

  set scannedUrl(value: string) {
    this.service.scannedUrl = value;
  }


  get showDialog(): boolean {
    return this.service.showDialog;
  }

  set showDialog(value: boolean) {
    this.service.showDialog = value;
  }

  startScan() {
    this.router.navigate(['/pdf-scanner'])
  }

  ngOnInit() {
    const originName: string = this.route.snapshot.params['origin']
    const scannedName: string = this.route.snapshot.params['scanned']
    if (originName) {
      this.service.getFileByName(originName)
        .subscribe(response => {
          console.log(response)
          this.savePDF(response, 'ORIGINAL')
        })
    }

    if (scannedName) {
      this.service.getFileByName(scannedName)
        .subscribe(response => {
          console.log(response)
          console.log(response)
          this.savePDF(response, 'SCANNED')
        })
    }
    const interval = setInterval(() => {
      this.loaderService.hide()
      clearInterval(interval)
    }, 2000)
  }


  private async readPdfFile(file: File, type: string) {

    try {
      const arrayBuffer = await file.arrayBuffer(); // Await the promise here
      const blob = new Blob([arrayBuffer], {type: 'application/pdf'});
      const fileUrl = URL.createObjectURL(blob);

      if (type === 'ORIGINAL') {
        this.originalUrl = fileUrl;
      } else if (type === 'SCANNED') {
        this.scannedUrl = fileUrl;
      }

      console.log(fileUrl);

      // Trigger change detection if necessary
      this.changeDetector.detectChanges();
    } catch (error) {
      console.error('Error reading PDF file:', error);
    }
  }

  savePDF(pdfBlob: Blob, type: string) {
    const file = new Blob([pdfBlob], {type: 'application/pdf'});
    const fileURL = URL.createObjectURL(file);
    // Storing the PDF in an object
    if (type === 'ORIGINAL') {
      this.originalUrl = fileURL;
    } else if (type === 'SCANNED') {
      this.scannedUrl = fileURL;
    }

    // You can now use `pdfObject` to manipulate the PDF.
  }

  openDialog() {
    this.showDialog = true
  }

  score(): string {
    const score = localStorage.getItem('score')
    if (score)
      return score
    else return '100';
  }

}
