import {Injectable} from '@angular/core';
import {HttpClient, HttpHeaders} from "@angular/common/http";
import {environment} from "../../../environments/environment";
import {Observable} from "rxjs";
import {ScanResponse} from "../../core/models/scan.response.model";

@Injectable({
  providedIn: 'root'
})
export class ScannerService {
  URL: string = environment.BASE_URL
  private _originalFile: File | null = null
  private _scannedFile: File | null = null
  private _showDialog: boolean = false
  private _originalUrl: string = ''
  private _scannedUrl: string = ''
  private _originalFileValidated: boolean | null = null
  private _scannedFileValidated: boolean | null = null

  constructor(private http: HttpClient) {
  }


  get originalFileValidated(): boolean | null {
    return this._originalFileValidated;
  }

  set originalFileValidated(value: boolean | null) {
    this._originalFileValidated = value;
  }

  get scannedFileValidated(): boolean | null {
    return this._scannedFileValidated;
  }

  set scannedFileValidated(value: boolean | null) {
    this._scannedFileValidated = value;
  }

  get originalUrl(): string {
    return this._originalUrl;
  }

  set originalUrl(value: string) {
    this._originalUrl = value;
  }

  get scannedUrl(): string {
    return this._scannedUrl;
  }

  set scannedUrl(value: string) {
    this._scannedUrl = value;
  }

  get showDialog(): boolean {
    return this._showDialog;
  }

  set showDialog(value: boolean) {
    this._showDialog = value;
  }

  get originalFile(): File | null {
    return this._originalFile;
  }

  set originalFile(value: File | null) {
    this._originalFile = value;
  }

  get scannedFile(): File | null {
    return this._scannedFile;
  }

  set scannedFile(value: File | null) {
    this._scannedFile = value;
  }

  public scanFile(original: File, scanned: File): Observable<ScanResponse> {
    const formData = new FormData();
    formData.set('original_pdf', original);
    formData.set('scanned_pdf', scanned);
    // @ts-ignore
    return this.http.post<ScanResponse>(`${this.URL}process_pdfs`, formData)
  }

  public getFileByName(fileName: string): Observable<Blob> {
    const headers = new HttpHeaders({
      'ngrok-skip-browser-warning': 'true'
    });
    // @ts-ignore
    return this.http.get<Blob>(`${this.URL}download/outputs/${fileName}`,
      {
        headers: headers,
        responseType: 'blob' as 'json'
      })
  }


}
